==> cbol-1.5.tgz: cbol-1.5/st.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 require("lang.php");
 /**** @ܼ ********/
  //W
 $PROGNAME='st.php';
 $READPROGNAME='t.php';
  //QueryO
 /************* GET ܼ ***************/
  $N=$_REQUEST['N'];//d 0Gtorrey 1:naves
  $keyword=$_REQUEST['keyword'];//dߤe
  if ($GBCODE==1)
        $keyword=trim(tranbig5($_REQUEST['keyword']));
  else
        $keyword=trim($_REQUEST['keyword']);      //d߸
  $keyword=str_replace('\'','\\\'',$keyword);
 if ($N==1) //naves
 {
  $dictname="naves";
  $keyword=strtoupper($keyword);
 }
 elseif ($N==0) //torrey
 {
  $dictname="torrey";
  $keyword=ucfirst($keyword);
 }
 elseif ($N==2) //torrey Ķ
 {
  $dictname="fhltorrey";
 }
 elseif ($N==3) //naves Ķ
 {
  $dictname="fhlnaves";
 }
 $oldkeyword=trim($_REQUEST['keyword']);
 	$revkey=stripslashes($keyword);
 	$revkey=$keyword;
 $QUERY="select  id,topic from $dictname where topic like '%$keyword%' order by topic DESC";
  //TableXSOѼ
 $tabout="border=1 align=\"center\"";
  //d߸ƪY
 	$THEADER=array("s","DD");
  //C@
 $PGNUM=50;
 // Primary Key	
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 require("strong.php");
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 if (strlen($keyword)==0)
 {
    $QUERY="select id,topic from $dictname order by topic DESC";
    $NOKEY=1;
 }
 /******** }ldƮw ********/
 if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 if ($numrow==0)
   {
	
   	echogb("dơAЭקd߱AdI");
	exit;
   }
 if ($numrow==1)
 {
      $ARAW=db_fetch_row($result,0); //Ū@O
      $TP=substr($ARAW[0],1);
      header("location: $READPROGNAME?k=$TP&N=$N");
      die('');
 }
 $numfield=db_NumFields($result);
 /******** LX ********/
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
	$PGEND=$numrow-1;
 }
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"N\" value=\"$N\">\n";
   echogb("<input type=\"submit\" name=\"submit1\" value=\"W@\">\n");
   echo "</form></center><br>\n";
 }
 $fpt=$PGBEG+1;
 echogb("<center>`@ $numrow ơAثeѲ $fpt }lL<br></center>\n");
 echo "<FONT COLOR=$COLOR><table $tabout>\n<tr>";
 $fpcnt=2;
 for ($fpt=0;$fpt<$fpcnt;$fpt++)
 {
   	$special=htmlspecialchars($THEADER[$fpt]);//SrBz
    	echogb("<td align=center>$special</td>");
 }
 echo "</tr>";
 /****uLX *****/
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      echo "<tr>";
      $ARAW=db_fetch_row($result,$a); //Ū@O
      $special=substr(htmlspecialchars($ARAW[0]),3);//SrBz
      $TP=substr($ARAW[0],1);
      echogb("<td><a href=\"$READPROGNAME?k=$TP&N=$N\">$special</a></td>");
      /****Bzg*****/
      $bibletex=trim($ARAW[1]);
      echo "<td>";
      if ($NOKEY!=1)
      {
      	$pos=strpos($bibletex,$revkey);
      	while (!($pos===false))
      	{
		$pretex=substr($bibletex,0,$pos);
        	$newpos=$pos+strlen($revkey);
		$bibletex=substr($bibletex,$newpos);
		$special=htmlspecialchars($pretex);
	
        	echogb("$special</font><font color=$KEYCOLOR>$revkey</font><font color=$COLOR>");
        	$pos=strpos($bibletex,$revkey);
      	}
      }
      $special=htmlspecialchars($bibletex);
	echogb("$special</td>");
      	echo "</tr>\n";
   }
   	echo "</table></font>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"N\" value=\"$N\">\n";
   echogb("<input type=\"submit\" name=\"submit1\" value=\"U@\">\n");
   echo "</form></center><br>\n";
 }
   echogb("<center><a href=\"$RETURNADD1\">sd</a></center><br>\n");
?>

==> cbol-1.7.tgz: cbol-1.7/st.php <==
<?php 
 require("config.php");
 require("dbconfig.php");
 require("lang.php");
 /**** @ܼ ********/
  //W
 $PROGNAME='st.php';
 $READPROGNAME='t.php';
  //QueryO
 /************* GET ܼ ***************/
  $N=(int) $_REQUEST['N'];//d 0Gtorrey 1:naves
  $keyword=$_REQUEST['keyword'];//dߤe
  if ($GBCODE==1)
        $keyword=trim(tranbig5($_REQUEST['keyword']));
  else
        $keyword=trim($_REQUEST['keyword']);      //d߸
  $keyword=str_replace('\'','\\\'',$keyword);
 if ($N==1) //naves
 {
  $dictname="naves";
  $keyword=strtoupper($keyword);
 }
 elseif ($N==0) //torrey
 {
  $dictname="torrey";
  $keyword=ucfirst($keyword);
 }
 elseif ($N==2) //torrey Ķ
 {
  $dictname="fhltorrey";
 }
 elseif ($N==3) //naves Ķ
 {
  $dictname="fhlnaves";
 }
 $oldkeyword=trim($_REQUEST['keyword']);
 	$revkey=stripslashes($keyword);
 	$revkey=$keyword;
 $QUERY="select  id,topic from $dictname where topic like '%$keyword%' order by topic DESC";
  //TableXSOѼ
 $tabout="border=1 align=\"center\"";
  //d߸ƪY
 	$THEADER=array("s","DD");
  //C@
 $PGNUM=50;
 // Primary Key	
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 require("strong.php");
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 if (strlen($keyword)==0)
 {
    $QUERY="select id,topic from $dictname order by topic DESC";
    $NOKEY=1;
 }
 /******** }ldƮw ********/
 if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 if ($numrow==0)
   {
	
   	echogb("dơAЭקd߱AdI");
	exit;
   }
 if ($numrow==1)
 {
      $ARAW=db_fetch_row($result,0); //Ū@O
      $TP=substr($ARAW[0],1);
      header("location: $READPROGNAME?k=$TP&N=$N");
      die('');
 }
 $numfield=db_NumFields($result);
 /******** LX ********/
 $PGEND=$PGBEG+$PGNUM-1;
 if ($PGEND>($numrow-1))
 {
	$PGEND=$numrow-1;
 }
 if ($PGBEG>=$PGNUM)
 {
   $a=$PGBEG-$PGNUM;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"N\" value=\"$N\">\n";
   echogb("<input type=\"submit\" name=\"submit1\" value=\"W@\">\n");
   echo "</form></center><br>\n";
 }
 $fpt=$PGBEG+1;
 echogb("<center>`@ $numrow ơAثeѲ $fpt }lL<br></center>\n");
 echo "<FONT COLOR=$COLOR><table $tabout>\n<tr>";
 $fpcnt=2;
 for ($fpt=0;$fpt<$fpcnt;$fpt++)
 {
   	$special=htmlspecialchars($THEADER[$fpt]);//SrBz
    	echogb("<td align=center>$special</td>");
 }
 echo "</tr>";
 /****uLX *****/
 for($a=$PGBEG;$a<=$PGEND;$a++)
   {
      echo "<tr>";
      $ARAW=db_fetch_row($result,$a); //Ū@O
      $special=substr(htmlspecialchars($ARAW[0]),3);//SrBz
      $TP=substr($ARAW[0],1);
      echogb("<td><a href=\"$READPROGNAME?k=$TP&N=$N\">$special</a></td>");
      /****Bzg*****/
      $bibletex=trim($ARAW[1]);
      echo "<td>";
      if ($NOKEY!=1)
      {
      	$pos=strpos($bibletex,$revkey);
      	while (!($pos===false))
      	{
		$pretex=substr($bibletex,0,$pos);
        	$newpos=$pos+strlen($revkey);
		$bibletex=substr($bibletex,$newpos);
		$special=htmlspecialchars($pretex);
	
        	echogb("$special</font><font color=$KEYCOLOR>$revkey</font><font color=$COLOR>");
        	$pos=strpos($bibletex,$revkey);
      	}
      }
      $special=htmlspecialchars($bibletex);
	echogb("$special</td>");
      	echo "</tr>\n";
   }
   	echo "</table></font>\n";
 if ($PGEND<($numrow-1))
 {
   $a=$PGEND+1;
   echo "<center><form method=\"POST\" action=\"$PROGNAME\">\n";
   echo "<input type=\"hidden\" name=\"PGBEG\" value=\"$a\">\n";
   echo "<input type=\"hidden\" name=\"keyword\" value=\"$oldkeyword\">\n";
   echo "<input type=\"hidden\" name=\"N\" value=\"$N\">\n";
   echogb("<input type=\"submit\" name=\"submit1\" value=\"U@\">\n");
   echo "</form></center><br>\n";
 }
   echogb("<center><a href=\"$RETURNADD1\">sd</a></center><br>\n");
?>
